@@ -46,3 +46,9 @@ class RandomModel(Model):
             size = len(self.__classLabels)
             index = random.randrange(size)
             return self.__classLabels[index]
+
+    def predictProbability(self, instance: Instance) -> dict:
+        result = {}
+        for classLabel in self.__classLabels:
+            result[classLabel] = 1.0 / len(self.__classLabels)
+        return result
